--[[
Loader for 
	BalancePowerTracker_Pipe
	BalancePowerTracker_Options
--]]
if (select(2,UnitClass("player"))~="DRUID") then 
	return
end

local addOns = {
	--[[["BalancePowerTracker_Pipe"] = {
		nick = "PIPE",
		loaded = false,
		description = "Provides PowerAuras the ability to read BPT's values.\n Energy values are used like other PowerAuras resources.\n Eclipse Direction:\n   0: Unsued.\n   1: Moon.\n   2: None.\n   3: Sun.",
		priority = 3,
		global = "BPT_PIPE_STATUS",
	},]]
	["BalancePowerTracker_Options"] = {
		nick = "OPT",
		loaded = false,
		description = "BPT's Options were moved into a separate AddOn in order to free memory.",
		priority = 1,
		global = "BPT_OPT_STATUS",
	}
} 
local function checkAll()
	for k,v in pairs(addOns) do
		if GetAddOnInfo(k) then
			v.loaded = IsAddOnLoaded(k)
		end
	end
	if not BalancePowerTracker_DB then BalancePowerTracker_DB = {} end
	if not BalancePowerTracker_DB.modules then BalancePowerTracker_DB.modules = {} end
	
	local optionsTable = { 
		name	= "BalancePowerTracker Loader",
		type	= 'group',
		args	= {
		}
	}
	
	for k,v in pairs(addOns) do
		local reason = select(6,GetAddOnInfo(k))
		local loaded;
	
		if BalancePowerTracker_DB.modules[v.nick] and not IsAddOnLoaded(k) then
			if not reason then
				loaded,reason = LoadAddOn(k) 
			end
			
			if loaded ~= 1 then
				local msg = "|c00a080ffBalancePowerTracker|r: Couldn't load: "..k
				if reason then
					msg = msg..": ".._G["ADDON_"..reason]..".";
				else
					msg = msg.."."
				end
				print(msg);
			end
		end
		v.loaded = IsAddOnLoaded(k)
		
		
		optionsTable.args["header"..k] = {
			type	= 'header',
			name    = k,
			order = v.priority*10+0,
		}
		optionsTable.args["info"..k] = {
			type	= 'description',
			name	= v.description,
			order = v.priority*10+1,
		}
		optionsTable.args["load"..k]= {
			type	= 'execute',
			name	= "Load",
			desc	= "Load "..k,
			disabled = function() return IsAddOnLoaded(k) or not select(5,GetAddOnInfo(k)) end, 
			func	= function () LoadAddOn(k)  end,
			order = v.priority*10+2,
		}
		optionsTable.args["loadOnLog"..k]= {
			type	= 'toggle',
			name	= "Load on Login",
			desc	= "Enable/Disable loading "..k.." on login.",
			get		= function () return BalancePowerTracker_DB.modules[v.nick] end,
			set		= function () BalancePowerTracker_DB.modules[v.nick] = not BalancePowerTracker_DB.modules[v.nick]; end,
			order = v.priority*10+3,
		}
		optionsTable.args["Ok"..k]= {
			type	= 'description',
			name	= function() local reason = select(6,GetAddOnInfo(k)) if reason then return "Status: ".._G["ADDON_"..reason].."." else return "Status: OK" end end,
			order = v.priority*10+4,
		}
		
		if v.nick == "LOG" then
			optionsTable.args["Show"..k]= {
				type	= 'execute',
				name	= "Show",
				desc	= "Show "..k.." UI",
				disabled = function() return not (LogBalancePowerTracker and _G[v.global]=="WORK") end, 
				func	= function () LogBalancePowerTracker.Show()  end,
				order = v.priority*10+5,
			}
		end
	end

	LibStub("AceConfig-3.0"):RegisterOptionsTable("BalancePowerTracker Loader",optionsTable,nil)
	LibStub("AceConfigDialog-3.0"):AddToBlizOptions("BalancePowerTracker Loader","BalancePowerTracker Loader")
end;

local LoaderFrame = CreateFrame("Frame",nil,UIParent);
LoaderFrame:SetScript("OnEvent",checkAll);
LoaderFrame:RegisterEvent("PLAYER_LOGIN");

BPTLoader = {}
function BPTLoader.load(nickname,all)
	for k,v in pairs(addOns) do
		if all or v.nick==nickname then
			local reason = select(6,GetAddOnInfo(k));
			local loaded;
			
			if not reason then
				loaded,reason = LoadAddOn(k) 
			end
			
			if loaded ~= 1 then
				local msg = "|c00a080ffBalancePowerTracker|r: Couldn't load: "..k
				if reason then
					msg = msg..": ".._G["ADDON_"..reason]..".";
				else
					msg = msg.."."
				end
				print(msg);
			end
			
			v.loaded = IsAddOnLoaded(k)
			
			if not all then
				return v.loaded;
			end
		end
	end
end
function BPTLoader.loadAll()
	BPTLoader.load(nil,true)
end

local BalancePowerTracker --TODO remove 
local dbug = false;
if not dbug then return end

-----------------------------------------------------------------------------------------------
do  --LOADER-----------------------------------------------------------------------------------
	BalancePowerTracker = {}
	local BalancePowerTracker = BalancePowerTracker
	BalancePowerTracker.name = "BalancePowerTracker"
	BalancePowerTracker.modules = {}
	
	local options = nil;
	local isDruid = select(2,UnitClass("player"))=="DRUID";
	
	local frame = CreateFrame("Frame",nil,UIParent);
	frame:RegisterEvent("ADDON_LOADED");
	frame:SetScript("OnEvent",function(_,_,name)
		if name == BalancePowerTracker.name then
			options = BalancePowerTracker_Options or {}
			local text = "|c00a080ffBalancePowerTracker v"..GetAddOnMetadata(BalancePowerTracker.name, "Version") .." MoP|r: "
			if isDruid then
				BalancePowerTracker.CheckAll()
				text = text.."Loaded!"
			else
				text = text.."Won't work."
			end
			if not (options.global and options.global.muted) then
				print(text);
			end
		end
	end)
	
	function BalancePowerTracker.CheckAll()
		if not (options and isDruid and BalancePowerTracker.modules and type(BalancePowerTracker.modules)=="table" ) then 
			return
		end
		
		for k,v in pairs(BalancePowerTracker.modules) do
			if not options[k] then options[k] = {} end
		
			if (not v.loaded) and (options[k].load or true ) then --TODO remove or true 
				v.LoadModule(options.global,options[k])
			elseif v.loaded then
				if not options[k].load then
					v.UnloadModule()
				else
					v.ReDraw()
				end
			end	
		end
	end
end

do  --WARNING TEXT---------------------------------------------------------------------------------
	if not (BalancePowerTracker and BalancePowerTracker.modules)then
		return
	end

	local me = {}
	local options = {};
	BalancePowerTracker.modules.warning_text = me;
	
	
	--[[TODO list
		sonido
		MSBT
		SHaredMedia
	
	]]
	
	local function DrawUI()
		if not me.frame then
			--Text frame
			me.frame = me.frame or CreateFrame("Frame","BalancePowerTracker_Warnings_Text_Frame",UIParent)
					
			me.frame:SetScript("OnMouseDown", function(self) self:StartMoving() end)
			me.frame:SetScript("OnMouseUp",   function(self) self:StopMovingOrSizing(); options.point,_,_,options.x,options.y = self:GetPoint() end)
			me.frame:SetScript("OnDragStop",  function(self) self:StopMovingOrSizing(); options.point,_,_,options.x,options.y = self:GetPoint() end)
		
			me.frame:SetClampedToScreen(true)
			me.frame:SetBackdrop({
				bgFile = "Interface\\Tooltips\\UI-Tooltip-Background",
				edgeFile = nil,
				tile = false, tileSize = 0, edgeSize = 12,
				insets = {top =2, bottom=2, left =2, right =2,},
			})
		
			--Text
			me.text = me.text or me.frame:CreateFontString(nil,"OVERLAY","GameFontNormal")
			me.text:ClearAllPoints();
			me.text:SetPoint("CENTER",0,0)
			
			--Flash frame
			me.flash = me.flash or CreateFrame("Frame", "BalancePowerTracker_Warnings_Flash_Frame",UIParent)
			me.flash:SetToplevel(true)
			me.flash:SetFrameStrata("FULLSCREEN_DIALOG")
			me.flash:SetAllPoints(UIParent)
			me.flash:EnableMouse(false)
			me.flash:Hide()
	
			--Flash texture
			me.flashtexture = me.flashtexture or me.flash:CreateTexture(nil, "BACKGROUND")
			me.flashtexture:SetTexture(0.0,1.0,1.0,.15)
			me.flashtexture:SetAllPoints(UIParent)
			me.flashtexture:SetAlpha(1)
			me.flashtexture:SetBlendMode("ADD")
		end
		
		options.font = options.font or "Fonts\\FRIZQT__.TTF"
		options.fontSize = options.fontSize or 30
		me.text:SetFont(options.font,options.fontSize)

		options.x = options.x or 0;
		options.y = options.y or 120;
		options.point = options.point or "CENTER";
		
		me.frame:ClearAllPoints();
		me.frame:SetPoint(options.point,options.x,options.y);
	
		options.scale = options.scale or 1;
		me.frame:SetScale(options.scale)
	
		options.strata = options.strata or "HIGH"
		me.frame:SetFrameStrata(options.strata)
		
		me.frame:SetWidth(options.fontSize*1.2)
		me.frame:SetHeight(options.fontSize*1.2);
		
		if options.testing or true then --TODO remove or true
			me.frame:SetMovable(true)
			me.frame:EnableMouse(true)
			me.frame:SetBackdropColor(0, 0, 0, .5)
			me.text:SetText("Move Me!")
			me.text:SetTextColor(1, 1, 1, 1)
			me.frame:Show();
		else
			me.frame:SetMovable(false)
			me.frame:EnableMouse(false)
			me.frame:SetBackdropColor(0, 0, 0, 0)
			me.frame:Hide();
		end
	end
	
	local function callback()
		--TODO
	
	
	
	end


	
	function me.ReDraw()
		if not me.loaded then return end
	
		DrawUI()
	end
	
	function me.LoadModule(opt)
		if me.loaded then return end
		
		options = opt
		me.loaded = true
		
		DrawUI()
		
		me.callbackId = LibBalancePowerTracker:RegisterCallback(callback);
	end
	
	function me.UnloadModule()
		if not me.loaded then return end
		me.loaded = false
	
		LibBalancePowerTracker:UnregisterCallback(me.callbackId)
	
		me.frame:Hide();
		me.flash:Hide();
	end
end






















